==> plugin%20Wao%20v2.4.8.zip: plugin Wao/paypals/paypal-return-paypals-table.php <==
<?php

 
function paypal_return_paypals_table($pp_table_or_widget = 'T'){
	if (isset($_GET['pp_method']) AND $_GET['pp_method']<>""){
		$pp_method = $_GET['pp_method'];
	}
	if (isset($_GET['pp_url_pais']) AND $_GET['pp_url_pais']<>""){
		$pp_url_pais = $_GET['pp_url_pais'];
	}
	if (isset($_GET['pp_table_or_widget']) AND $_GET['pp_table_or_widget']<>""){
		$pp_table_or_widget = $_GET['pp_table_or_widget'];
	}

	if($pp_table_or_widget=='W'){// Llamado por paypal-show-widget.php para devolver json con paypals de todos los paises
		global $wpdb;
		//DE HECHO ES MULTISITE
		$sites = get_sites(array('archived' => 0));
		$i=0;
		switch_to_blog($GLOBALS['pp_server_id']);
			$xdias=get_paypal_option('xdias');//debe ser del sitio principal
			if(empty($xdias)){
				$xdias=21;
			}
		restore_current_blog();
		foreach ( $sites as $site ) {
			switch_to_blog( $site->blog_id );
				$sitio = get_option( 'blogname' );
				$url = get_option( 'home' );
				$sitio1 = strpos(strtoupper($sitio),'MANUALS');
				if(is_bool($sitio1)){
					$pp_active_id = get_option('_pp_active_id'); // Estoy en la tienda
					$pm=get_paypal_payment_method();
					switch_to_blog($GLOBALS['pp_server_id']);
						if ($pm=='checkout'){
							$pp_user_name=get_post_meta($pp_active_id,'_liveAPIUsername',true);
							$paypalreceiver=get_post_meta($pp_active_id,'_liveAPIUsername',true);
							$paypalreceiver=str_replace("_api1.","@",$paypalreceiver);
						} 
						if ($pm=='payments'){
							$pp_user_name=get_post_meta($pp_active_id,'_liveEmailAddress',true);
							$paypalreceiver=get_post_meta($pp_active_id,'_liveEmailAddress',true);
						}
					restore_current_blog();
					
					// con este pp
					$pp_date_changed = get_option('_paypalupdatedate');
					$colorcod=paypal_color_id($pp_active_id);
					$colorcod=paypal_color_span($colorcod);

					$ppactivesales=ppactivesales_id($pp_active_id); 
					$ppdaysales=ppdaysales_id($pp_active_id); 
					$ppmonthsales=ppmonthsales_id($pp_active_id); 
					$pplifetimesales=pplifetimesales_id($pp_active_id); 
					$ppmonthlimit=ppmonthlimit_id($pp_active_id); 
					$ppgracedate=ppgracedate($pp_active_id); 
					
					$retorno[$i]['sitio']=$sitio;
					$retorno[$i]['url']=$url;
					$retorno[$i]['site_id']=$site->blog_id ;
					$retorno[$i]['pp_user_name']=$pp_user_name;
					$retorno[$i]['colorcod']=$colorcod;
					$retorno[$i]['pp_date_changed']=$pp_date_changed;
					$retorno[$i]['ppactivesales']=$ppactivesales;
					$retorno[$i]['ppdaysales']=$ppdaysales;
					$retorno[$i]['ppmonthsales']=$ppmonthsales;
					$retorno[$i]['ppmonthlimit']=$ppmonthlimit;
					$retorno[$i]['pp_active_id']=$pp_active_id;
					$retorno[$i]['pplifetimesales']=$pplifetimesales;
					$retorno[$i]['ppmethod']=$pm;
					$retorno[$i]['xdias']=xdias($xdias, $paypalreceiver);
					$retorno[$i]['xdias_number']=$xdias;
					$retorno[$i]['ppgracedate']=$ppgracedate;
					$retorno[$i++]['paypalreceiver']=$paypalreceiver;
					}//fin de sitio <> manuals
			restore_current_blog();
		}//fin de foreach
		$salida = json_encode($retorno);
		return $salida;
	}

	if($pp_table_or_widget=='P'){// Llamado por paypal-show-widget.php para devolver json con paypal del pais actual
		$pp_active_id = get_option('_pp_active_id'); // Estoy en la tienda
		$pp_date_changed = get_option('_paypalupdatedate');
		$pm=get_paypal_payment_method();
		if(is_multisite()){
			switch_to_blog($GLOBALS['pp_server_id']);
		}
			if ($pm=='checkout'){
				$pp_user_name=get_post_meta($pp_active_id,'_liveAPIUsername',true);
			} 
			if ($pm=='payments'){
				$pp_user_name=get_post_meta($pp_active_id,'_liveEmailAddress',true);
			}
			//$pp_user_name=get_post_meta($pp_active_id,'_liveAPIUsername',true);
			$colorcod=paypal_color_id($pp_active_id); 
			$colorcod=paypal_color_span($colorcod);
			$retorno[0]['colorcod']=$colorcod;
			$retorno[0]['pp_user_name']=$pp_user_name;
			$retorno[0]['pp_date_changed']=$pp_date_changed;
			$retorno[0]['ppactivesales']=ppactivesales_id($pp_active_id); 
			$retorno[0]['ppdaysales']=ppdaysales_id($pp_active_id); 
			$retorno[0]['ppmonthsales']=ppmonthsales_id($pp_active_id); 
			$retorno[0]['pplifetimesales']=pplifetimesales_id($pp_active_id); 
			$retorno[0]['pp_active_id']=$pp_active_id;
			$salida = json_encode($retorno);
		if(is_multisite()){
			restore_current_blog();
		}
		return $salida;
	}

	if($pp_table_or_widget=='T'){//  Llamado por paypal-client-functions.php para devolver json filtrado por status

		//if(current_user_can('ver_paypals')){
		if(true){
			//Obtenemos el total de paypals
			if(is_multisite()){
				$blog_id = get_current_blog_id();
				switch_to_blog($GLOBALS['pp_server_id']);//se ubica como servidor paypal
			}
				global $wpdb;
				$q="SELECT COUNT(ID) FROM {$wpdb->prefix}posts WHERE post_status='publish' AND post_type='paypals'";
				$total=$wpdb->get_var($q);
				$args = array(
					'posts_per_page'   => $total,
					'offset'           => 0,
					'category'         => '',
					'orderby'          => 'post_title',
					'order'            => 'ASC',
					'post_type'        => 'paypals',
					'post_status'      => 'publish',
					'suppress_filters' => true,
					'meta_query' => array(
						array(
							'key' => '_ppstatus',
							'value' => 'Reserva',
							'compare' => '=',
						)
					)			
				); 
				$paypls = get_posts($args);
				$i=1;
				foreach ($paypls as $paypl){
					$id =$paypl->ID;
					$print_tr=FALSE;
					if(!is_multisite()){//si no es multisite, mostrar todos los paypals
						$print_tr=TRUE;
					}else{
						$sites=get_post_meta($id,'_forsites',true);
						if (!empty($sites)){//si es multisite filtramos por pais
							if(in_array($blog_id,$sites)){
								$print_tr=TRUE;
							}//if in array blog id END
						}
					}//fin de is multisite. Permite filtrar 
					if($print_tr){
						$retorno[]=array(
							'paypal_id' => $paypl->ID,
							'post_title' => $paypl->post_title,
							'liveAPIUsername' => get_post_meta($id,'_liveAPIUsername',true),
							'liveAPIPassword' => get_post_meta($id,'_liveAPIPassword',true),
							'liveAPISignature' => get_post_meta($id,'_liveAPISignature',true),
							'liveEmailAddress' => get_post_meta($id,'_liveEmailAddress',true),
							'liveMerchantId' => get_post_meta($id,'_liveMerchantId',true),
							'liveClientId' => get_post_meta($id,'_liveClientId',true),
							'liveSecretKey' => get_post_meta($id,'_liveSecretKey',true),
							'ppcategory' => get_post_meta($id,'_ppcategory',true),
							'ppactivesales' => get_post_meta($id,'_ppactivesales',true),
							'ppdaysales' => get_post_meta($id,'_ppdaysales',true),
							'ppmonthsales' => get_post_meta($id,'_ppmonthsales',true),
							'pplifetimesales' => get_post_meta($id,'_pplifetimesales',true),
							'ppstatus' => get_post_meta($id,'_ppstatus',true)
						);
					}//fin de si print_tr
				}//foreach paypls END
				$salida = json_encode($retorno);
			if(is_multisite()){
				restore_current_blog();
			}
			return $salida;
		}
	}//fin de if T
}// fin de funcion

//devolver un punto de acuerdo al color del paypal
//llevar a paypal return paypals table

//add_shortcode('paypals_table','paypal_return_paypals_table');
function ppactivesales_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppactivesales',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppactivesales',true);
	}
	return $retorno;
}

function ppdaysales_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppdaysales',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppdaysales',true);
	}
	return $retorno;
}

function ppmonthsales_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppmonthsales',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppmonthsales',true);
	}
	return $retorno;
}

function pplifetimesales_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_pplifetimesales',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_pplifetimesales',true);
	}
	return $retorno;
}

function ppmonthlimit_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppmonthlimit',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppmonthlimit',true);
	}
	return $retorno;
}
function ppgracedate($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppgracedate',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppgracedate',true);
	}
	return $retorno;
}

function paypal_color_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppcategory',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppcategory',true);
	}
	return $retorno;
}

==> plugin%20Wao%20v2.5.31.zip: plugin Wao/paypals/paypal-return-paypals-table.php <==
<?php

 
function paypal_return_paypals_table($pp_table_or_widget = 'T'){
	if (isset($_GET['pp_method']) AND $_GET['pp_method']<>""){
		$pp_method = $_GET['pp_method'];
	}
	if (isset($_GET['pp_url_pais']) AND $_GET['pp_url_pais']<>""){
		$pp_url_pais = $_GET['pp_url_pais'];
	}
	if (isset($_GET['pp_table_or_widget']) AND $_GET['pp_table_or_widget']<>""){
		$pp_table_or_widget = $_GET['pp_table_or_widget'];
	}

	if($pp_table_or_widget=='W'){// Llamado por paypal-show-widget.php para devolver json con paypals de todos los paises
		global $wpdb;
		//DE HECHO ES MULTISITE
		$sites = get_sites(array('archived' => 0));
		$i=0;
		switch_to_blog($GLOBALS['pp_server_id']);
			$xdias=get_paypal_option('xdias');//debe ser del sitio principal
			if(empty($xdias)){
				$xdias=21;
			}
		restore_current_blog();
		foreach ( $sites as $site ) {
			switch_to_blog( $site->blog_id );
			// Verificar si el plugin está activo
			if (is_plugin_active('woocommerce-gateway-paypal-express-checkout/woocommerce-gateway-paypal-express-checkout.php')) {
				// El plugin está activo
				$plugin_activo = TRUE;
			} else {
				// El plugin no está activo
				$plugin_activo = FALSE;
			}
				$sitio = get_option( 'blogname' );
				$url = get_option( 'home' );
				$sitio1 = strpos(strtoupper($sitio),'MANUALS');
				if(is_bool($sitio1)){
					$pp_active_id = get_option('_pp_active_id'); // Estoy en la tienda
					$pm=get_paypal_payment_method();
					switch_to_blog($GLOBALS['pp_server_id']);
						if ($pm=='checkout'){
							$pp_user_name=get_post_meta($pp_active_id,'_liveAPIUsername',true);
							$paypalreceiver=get_post_meta($pp_active_id,'_liveAPIUsername',true);
							$paypalreceiver=str_replace("_api1.","@",$paypalreceiver);
						} 
						if ($pm=='payments'){
							$pp_user_name=get_post_meta($pp_active_id,'_liveEmailAddress',true);
							$paypalreceiver=get_post_meta($pp_active_id,'_liveEmailAddress',true);
						}
					restore_current_blog();
					
					// con este pp
					$pp_date_changed = get_option('_paypalupdatedate');
					$colorcod=paypal_color_id($pp_active_id);
					$colorcod=$plugin_activo?paypal_color_span($colorcod):paypal_color_span('x');
					//$colorcod=$plugin_activo;

					$ppactivesales=ppactivesales_id($pp_active_id); 
					$ppdaysales=ppdaysales_id($pp_active_id); 
					$ppmonthsales=ppmonthsales_id($pp_active_id); 
					$pplifetimesales=pplifetimesales_id($pp_active_id); 
					$ppmonthlimit=ppmonthlimit_id($pp_active_id); 
					$ppgracedate=ppgracedate($pp_active_id); 
					
					$retorno[$i]['sitio']=$sitio;
					$retorno[$i]['url']=$url;
					$retorno[$i]['site_id']=$site->blog_id ;
					$retorno[$i]['pp_user_name']=$pp_user_name;
					$retorno[$i]['colorcod']=$colorcod;
					$retorno[$i]['pp_date_changed']=$pp_date_changed;
					$retorno[$i]['ppactivesales']=$ppactivesales;
					$retorno[$i]['ppdaysales']=$ppdaysales;
					$retorno[$i]['ppmonthsales']=$ppmonthsales;
					$retorno[$i]['ppmonthlimit']=$ppmonthlimit;
					$retorno[$i]['pp_active_id']=$pp_active_id;
					$retorno[$i]['pplifetimesales']=$pplifetimesales;
					$retorno[$i]['ppmethod']=$pm;
					$retorno[$i]['xdias']=xdias($xdias, $paypalreceiver);
					$retorno[$i]['xdias_number']=$xdias;
					$retorno[$i]['ppgracedate']=$ppgracedate;
					$retorno[$i]['plugin_activo']=$plugin_activo;
					$retorno[$i++]['paypalreceiver']=$paypalreceiver;
					}//fin de sitio <> manuals
			restore_current_blog();
		}//fin de foreach
		$salida = json_encode($retorno);
		return $salida;
	}

	if($pp_table_or_widget=='P'){// Llamado por paypal-show-widget.php para devolver json con paypal del pais actual
		$pp_active_id = get_option('_pp_active_id'); // Estoy en la tienda
		$pp_date_changed = get_option('_paypalupdatedate');
		$pm=get_paypal_payment_method();
		if(is_multisite()){
			switch_to_blog($GLOBALS['pp_server_id']);
		}
			if ($pm=='checkout'){
				$pp_user_name=get_post_meta($pp_active_id,'_liveAPIUsername',true);
			} 
			if ($pm=='payments'){
				$pp_user_name=get_post_meta($pp_active_id,'_liveEmailAddress',true);
			}
			//$pp_user_name=get_post_meta($pp_active_id,'_liveAPIUsername',true);
			$colorcod=paypal_color_id($pp_active_id); 
			$colorcod=paypal_color_span($colorcod);
			$retorno[0]['colorcod']=$colorcod;
			$retorno[0]['pp_user_name']=$pp_user_name;
			$retorno[0]['pp_date_changed']=$pp_date_changed;
			$retorno[0]['ppactivesales']=ppactivesales_id($pp_active_id); 
			$retorno[0]['ppdaysales']=ppdaysales_id($pp_active_id); 
			$retorno[0]['ppmonthsales']=ppmonthsales_id($pp_active_id); 
			$retorno[0]['pplifetimesales']=pplifetimesales_id($pp_active_id); 
			$retorno[0]['pp_active_id']=$pp_active_id;
			$salida = json_encode($retorno);
		if(is_multisite()){
			restore_current_blog();
		}
		return $salida;
	}

	if($pp_table_or_widget=='T'){//  Llamado por paypal-client-functions.php para devolver json filtrado por status

		//if(current_user_can('ver_paypals')){
		if(true){
			//Obtenemos el total de paypals
			if(is_multisite()){
				$blog_id = get_current_blog_id();
				switch_to_blog($GLOBALS['pp_server_id']);//se ubica como servidor paypal
			}
				global $wpdb;
				$q="SELECT COUNT(ID) FROM {$wpdb->prefix}posts WHERE post_status='publish' AND post_type='paypals'";
				$total=$wpdb->get_var($q);
				$args = array(
					'posts_per_page'   => $total,
					'offset'           => 0,
					'category'         => '',
					'orderby'          => 'post_title',
					'order'            => 'ASC',
					'post_type'        => 'paypals',
					'post_status'      => 'publish',
					'suppress_filters' => true,
					'meta_query' => array(
						array(
							'key' => '_ppstatus',
							'value' => 'Reserva',
							'compare' => '=',
						)
					)			
				); 
				$paypls = get_posts($args);
				$i=1;
				foreach ($paypls as $paypl){
					$id =$paypl->ID;
					$print_tr=FALSE;
					if(!is_multisite()){//si no es multisite, mostrar todos los paypals
						$print_tr=TRUE;
					}else{
						$sites=get_post_meta($id,'_forsites',true);
						if (!empty($sites)){//si es multisite filtramos por pais
							if(in_array($blog_id,$sites)){
								$print_tr=TRUE;
							}//if in array blog id END
						}
					}//fin de is multisite. Permite filtrar 
					if($print_tr){
						$retorno[]=array(
							'paypal_id' => $paypl->ID,
							'post_title' => $paypl->post_title,
							'liveAPIUsername' => get_post_meta($id,'_liveAPIUsername',true),
							'liveAPIPassword' => get_post_meta($id,'_liveAPIPassword',true),
							'liveAPISignature' => get_post_meta($id,'_liveAPISignature',true),
							'liveEmailAddress' => get_post_meta($id,'_liveEmailAddress',true),
							'liveMerchantId' => get_post_meta($id,'_liveMerchantId',true),
							'liveClientId' => get_post_meta($id,'_liveClientId',true),
							'liveSecretKey' => get_post_meta($id,'_liveSecretKey',true),
							'ppcategory' => get_post_meta($id,'_ppcategory',true),
							'ppactivesales' => get_post_meta($id,'_ppactivesales',true),
							'ppdaysales' => get_post_meta($id,'_ppdaysales',true),
							'ppmonthsales' => get_post_meta($id,'_ppmonthsales',true),
							'pplifetimesales' => get_post_meta($id,'_pplifetimesales',true),
							'ppstatus' => get_post_meta($id,'_ppstatus',true)
						);
					}//fin de si print_tr
				}//foreach paypls END
				$salida = json_encode($retorno);
			if(is_multisite()){
				restore_current_blog();
			}
			return $salida;
		}
	}//fin de if T
}// fin de funcion

//devolver un punto de acuerdo al color del paypal
//llevar a paypal return paypals table

//add_shortcode('paypals_table','paypal_return_paypals_table');
function ppactivesales_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppactivesales',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppactivesales',true);
	}
	return $retorno;
}

function ppdaysales_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppdaysales',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppdaysales',true);
	}
	return $retorno;
}

function ppmonthsales_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppmonthsales',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppmonthsales',true);
	}
	return $retorno;
}

function pplifetimesales_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_pplifetimesales',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_pplifetimesales',true);
	}
	return $retorno;
}

function ppmonthlimit_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppmonthlimit',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppmonthlimit',true);
	}
	return $retorno;
}
function ppgracedate($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppgracedate',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppgracedate',true);
	}
	return $retorno;
}

function paypal_color_id($paypal_id){
	if(is_multisite()){
		switch_to_blog($GLOBALS['pp_server_id']);
			$retorno = get_post_meta($paypal_id,'_ppcategory',true);
		restore_current_blog();
	}else{
		$retorno = get_post_meta($paypal_id,'_ppcategory',true);
	}
	return $retorno;
}
